{ config, pkgs, ... }:

{
  imports = [ # Include the results of the hardware scan.
    ./hardware-configuration.nix
    ../../modules/system/desktop/amd.nix
    ../../modules/system/desktop/hyprland.nix
    ../../modules/system/desktop/bluetooth.nix
    ../../modules/system/programs/steam.nix
    ../../modules/system/programs/syncthing.nix
    ../../modules/system/programs/thunar.nix
    ../../modules/system/programs/virtualization.nix
    ../../modules/system/utils/common.nix
    ../../modules/system/utils/fprint.nix
    ../../modules/system/utils/garbage-collection.nix
    ../../modules/system/utils/locale.nix
  ];

  nix.settings = {
    experimental-features = [ "nix-command" "flakes" ];

    substituters = [
      "http://binarycache.example.com"
      "https://nix-community.cachix.org"
      "https://cache.nixos.org/"
      "https://cache.garnix.io"
    ];
    trusted-public-keys = [
      "binarycache.example.com-1:dsafdafDFW123fdasfa123124FADSAD"
      "nix-community.cachix.org-1:mB9FSh9qf2dCimDSUo8Zy7bkq5CX+/rkCWyvRCYg3Fs="
      "cache.garnix.io:CTFPyKSLcx5RMJKfLo5EEPUObbA78b0YQ2DTCJXqr9g="
    ];
  };

  # Bootloader.
  boot.loader.efi.canTouchEfiVariables = true;
  boot.loader.grub = {
    enable = true;
    efiSupport = true;
    device = "nodev";
  };

  networking.hostName = "xv-laptop"; # Define your hostname.

  users.users.xeovalyte = {
    isNormalUser = true;
    description = "Timo Boomers";
    extraGroups = [ "networkmanager" "wheel" "dialout" ];
  };

  services.printing.enable = true;

  system.stateVersion = "23.11";

}
